# jumparound

Quickly jump around between your projects.

## Installation

```
python3 -m pip install --user pipx
python3 -m pipx ensurepath
python3 -m pipx install jumparound
```

## Usage

`jumparound` can be used on its own or as a part of other scripts. The most common usage is in
conjunction with `cd`.

```sh
cd $("jumparound to")
```

## Development

### Setup

* Have python `poetry` installed.
* Clone this repository.
* Run `make setup`
